@@ -56,8 +56,8 @@ logger = logging.getLogger("wgpu")  # noqa
 apidiff = ApiDiff()
 
 # The wgpu-native version that we target/expect
-__version__ = "0.10.4.1"
-__commit_sha__ = "b4dd62d1781c923ae0b52195fb9e710a7fc6b177"
+__version__ = "0.11.0.1"
+__commit_sha__ = "9d962ef667ef6006cca7bac7489d5bf303a2a244"
 version_info = tuple(map(int, __version__.split(".")))
 check_expected_version(version_info)  # produces a warning on mismatch
 
@@ -445,10 +445,10 @@ class GPUAdapter(base.GPUAdapter):
         # H: chain: WGPUChainedStruct, nativeFeatures: WGPUNativeFeature, label: char*, tracePath: char*
         extras = new_struct_p(
             "WGPUDeviceExtras *",
-            label=to_c_label(label),
             tracePath=c_trace_path,
             nativeFeatures=lib.WGPUNativeFeature_TEXTURE_ADAPTER_SPECIFIC_FORMAT_FEATURES,
             # not used: chain
+            # not used: label
         )
         extras.chain.sType = lib.WGPUSType_DeviceExtras
 
@@ -464,9 +464,10 @@ class GPUAdapter(base.GPUAdapter):
         for key, val in required_limits.items():
             setattr(c_limits, to_camel_case(key), val)
 
-        # H: nextInChain: WGPUChainedStruct *, requiredFeaturesCount: int, requiredFeatures: WGPUFeatureName *, requiredLimits: WGPURequiredLimits *
+        # H: nextInChain: WGPUChainedStruct *, label: char *, requiredFeaturesCount: int, requiredFeatures: WGPUFeatureName *, requiredLimits: WGPURequiredLimits *
         struct = new_struct_p(
             "WGPUDeviceDescriptor *",
+            label=to_c_label(label),
             nextInChain=ffi.cast("WGPUChainedStruct * ", extras),
             requiredFeaturesCount=0,
             requiredFeatures=ffi.new("WGPUFeatureName []", []),
@@ -844,14 +845,23 @@ class GPUDevice(base.GPUDevice, GPUObjectBase):
         id = lib.wgpuDeviceCreatePipelineLayout(self._internal, struct)
         return GPUPipelineLayout(label, id, self, bind_group_layouts)
 
-    def create_shader_module(self, *, label="", code: str, source_map: dict = None):
-
+    def create_shader_module(
+        self,
+        *,
+        label="",
+        code: str,
+        source_map: dict = None,
+        hints: "Dict[str, structs.ShaderModuleCompilationHint]" = None,
+    ):
+        if hints:
+            for val in hints.values():
+                check_struct("ShaderModuleCompilationHint", val)
         if isinstance(code, str):
             # WGSL
-            # H: chain: WGPUChainedStruct, source: char *
+            # H: chain: WGPUChainedStruct, code: char *
             source_struct = new_struct_p(
                 "WGPUShaderModuleWGSLDescriptor *",
-                source=ffi.new("char []", code.encode()),
+                code=ffi.new("char []", code.encode()),
                 # not used: chain
             )
             source_struct[0].chain.next = ffi.NULL
@@ -1151,7 +1161,7 @@ class GPUDevice(base.GPUDevice, GPUObjectBase):
             fragment=fragment,
         )
 
-    def create_command_encoder(self, *, label="", measure_execution_time: bool = False):
+    def create_command_encoder(self, *, label=""):
         # H: nextInChain: WGPUChainedStruct *, label: char *
         struct = new_struct_p(
             "WGPUCommandEncoderDescriptor *",
@@ -1177,14 +1187,7 @@ class GPUDevice(base.GPUDevice, GPUObjectBase):
         raise NotImplementedError()
 
     # FIXME: new method to implement
-    def create_query_set(
-        self,
-        *,
-        label="",
-        type: "enums.QueryType",
-        count: int,
-        pipeline_statistics: "List[enums.PipelineStatisticName]" = [],
-    ):
+    def create_query_set(self, *, label="", type: "enums.QueryType", count: int):
         raise NotImplementedError()
 
     def _destroy(self):
@@ -1421,12 +1424,21 @@ class GPUCommandBuffer(base.GPUCommandBuffer, GPUObjectBase):
 
 
 class GPUCommandEncoder(base.GPUCommandEncoder, GPUObjectBase):
-    def begin_compute_pass(self, *, label=""):
-        # H: nextInChain: WGPUChainedStruct *, label: char *
+    def begin_compute_pass(
+        self,
+        *,
+        label="",
+        timestamp_writes: "List[structs.ComputePassTimestampWrite]" = [],
+    ):
+        for val in timestamp_writes:
+            check_struct("ComputePassTimestampWrite", val)
+        # H: nextInChain: WGPUChainedStruct *, label: char *, timestampWriteCount: int, timestampWrites: WGPUComputePassTimestampWrite *
         struct = new_struct_p(
             "WGPUComputePassDescriptor *",
             label=to_c_label(label),
             # not used: nextInChain
+            # not used: timestampWriteCount
+            # not used: timestampWrites
         )
         # H: WGPUComputePassEncoder f(WGPUCommandEncoder commandEncoder, WGPUComputePassDescriptor const * descriptor)
         raw_pass = lib.wgpuCommandEncoderBeginComputePass(self._internal, struct)
@@ -1439,8 +1451,11 @@ class GPUCommandEncoder(base.GPUCommandEncoder, GPUObjectBase):
         color_attachments: "List[structs.RenderPassColorAttachment]",
         depth_stencil_attachment: "structs.RenderPassDepthStencilAttachment" = None,
         occlusion_query_set: "GPUQuerySet" = None,
+        timestamp_writes: "List[structs.RenderPassTimestampWrite]" = [],
     ):
         # Note that occlusion_query_set is ignored because wgpu-native does not have it.
+        for val in timestamp_writes:
+            check_struct("RenderPassTimestampWrite", val)
 
         c_color_attachments_list = []
         for color_attachment in color_attachments:
@@ -1508,7 +1523,7 @@ class GPUCommandEncoder(base.GPUCommandEncoder, GPUObjectBase):
                 ),
             )
 
-        # H: nextInChain: WGPUChainedStruct *, label: char *, colorAttachmentCount: int, colorAttachments: WGPURenderPassColorAttachment *, depthStencilAttachment: WGPURenderPassDepthStencilAttachment *, occlusionQuerySet: WGPUQuerySet
+        # H: nextInChain: WGPUChainedStruct *, label: char *, colorAttachmentCount: int, colorAttachments: WGPURenderPassColorAttachment *, depthStencilAttachment: WGPURenderPassDepthStencilAttachment *, occlusionQuerySet: WGPUQuerySet, timestampWriteCount: int, timestampWrites: WGPURenderPassTimestampWrite *
         struct = new_struct_p(
             "WGPURenderPassDescriptor *",
             label=to_c_label(label),
@@ -1517,6 +1532,8 @@ class GPUCommandEncoder(base.GPUCommandEncoder, GPUObjectBase):
             depthStencilAttachment=c_depth_stencil_attachment,
             # not used: occlusionQuerySet
             # not used: nextInChain
+            # not used: timestampWriteCount
+            # not used: timestampWrites
         )
 
         # H: WGPURenderPassEncoder f(WGPUCommandEncoder commandEncoder, WGPURenderPassDescriptor const * descriptor)
@@ -1763,6 +1780,10 @@ class GPUCommandEncoder(base.GPUCommandEncoder, GPUObjectBase):
             # H: void f(WGPUCommandEncoder commandEncoder)
             internal  # lib.wgpuCommandEncoderDrop(internal)  # Causes 'Cannot remove a vacant resource'
 
+    # FIXME: new method to implement
+    def clear_buffer(self, buffer, offset=0, size=None):
+        raise NotImplementedError()
+
 
 class GPUProgrammablePassEncoder(base.GPUProgrammablePassEncoder):
     def set_bind_group(
@@ -1859,10 +1880,6 @@ class GPUComputePassEncoder(
         # H: void f(WGPUComputePassEncoder computePassEncoder)
         lib.wgpuComputePassEncoderEndPass(self._internal)
 
-    # FIXME: new method to implement
-    def write_timestamp(self, query_set, query_index):
-        raise NotImplementedError()
-
     def _destroy(self):
         if self._internal is not None and lib is not None:
             self._internal, internal = None, self._internal
@@ -1995,10 +2012,6 @@ class GPURenderPassEncoder(
     def end_occlusion_query(self):
         raise NotImplementedError()
 
-    # FIXME: new method to implement
-    def write_timestamp(self, query_set, query_index):
-        raise NotImplementedError()
-
 
 class GPURenderBundleEncoder(
     base.GPURenderBundleEncoder,
