@@ -7,7 +7,7 @@ On Linux, install the glfw lib using ``sudo apt install libglfw3``,
 or ``sudo apt install libglfw3-wayland`` when using Wayland.
 """
 
-from collections import defaultdict
+
 import os
 import sys
 import time
@@ -17,7 +17,7 @@ import traceback
 
 import glfw
 
-from .base import WgpuCanvasBase
+from .base import WgpuCanvasBase, WgpuAutoGui
 
 
 # Make sure that glfw is new enough
@@ -122,12 +122,13 @@ KEY_MAP_MOD = {
 }
 
 
-class GlfwWgpuCanvas(WgpuCanvasBase):
+class GlfwWgpuCanvas(WgpuAutoGui, WgpuCanvasBase):
     """A glfw window providing a wgpu canvas."""
 
     # See https://www.glfw.org/docs/latest/group__window.html
 
     def __init__(self, *, size=None, title=None, **kwargs):
+        ensure_app()
         super().__init__(**kwargs)
 
         # Handle inputs
@@ -151,7 +152,6 @@ class GlfwWgpuCanvas(WgpuCanvasBase):
         self._need_draw = False
         self._request_draw_timer_running = False
         self._changing_pixel_ratio = False
-        self._event_handlers = defaultdict(set)
 
         # Register ourselves
         all_glfw_canvases.add(self)
@@ -256,8 +256,8 @@ class GlfwWgpuCanvas(WgpuCanvasBase):
             screen_ratio = ssize[0] / psize[0]
             glfw.set_window_size(
                 self._window,
-                int(new_logical_size[0] * pixel_ratio / screen_ratio),
-                int(new_logical_size[1] * pixel_ratio / screen_ratio),
+                int(new_logical_size[0] * pixel_ratio * screen_ratio),
+                int(new_logical_size[1] * pixel_ratio * screen_ratio),
             )
         # If this causes the widget size to change, then _on_size_change will
         # be called, but we may want force redetermining the size.
@@ -324,71 +324,6 @@ class GlfwWgpuCanvas(WgpuCanvasBase):
             sys.last_type, sys.last_value, sys.last_traceback = exc_info
             traceback.print_exception(*exc_info)
 
-    def handle_event(self, event):
-        """Handle an incoming event.
-
-        Subclasses can overload this method. Events include widget
-        resize, mouse/touch interaction, key events, and more. An event
-        is a dict with at least the key event_type. For details, see
-        https://jupyter-rfb.readthedocs.io/en/latest/events.html
-        """
-        event_type = event.get("event_type")
-        for callback in self._event_handlers[event_type]:
-            callback(event)
-
-    def add_event_handler(self, *args):
-        """Register an event handler.
-
-        Arguments:
-            callback (callable): The event handler. Must accept a
-                single event argument.
-            *types (list of strings): A list of event types.
-
-        For the available events, see
-        https://jupyter-rfb.readthedocs.io/en/latest/events.html
-
-        Can also be used as a decorator.
-
-        Example:
-
-        .. code-block:: py
-
-            def my_handler(event):
-                print(event)
-
-            canvas.add_event_handler(my_handler, "pointer_up", "pointer_down")
-
-        Decorator usage example:
-
-        .. code-block:: py
-
-            @canvas.add_event_handler("pointer_up", "pointer_down")
-            def my_handler(event):
-                print(event)
-        """
-        decorating = not callable(args[0])
-        callback = None if decorating else args[0]
-        types = args if decorating else args[1:]
-
-        def decorator(_callback):
-            for type in types:
-                self._event_handlers[type].add(_callback)
-            return _callback
-
-        if decorating:
-            return decorator
-        return decorator(callback)
-
-    def remove_event_handler(self, callback, *types):
-        """Unregister an event handler.
-
-        Arguments:
-            callback (callable): The event handler.
-            *types (list of strings): A list of event types.
-        """
-        for type in types:
-            self._event_handlers[type].remove(callback)
-
     # User events
 
     def _on_mouse_button(self, window, but, action, mods):
@@ -548,8 +483,11 @@ class GlfwWgpuCanvas(WgpuCanvasBase):
 WgpuCanvas = GlfwWgpuCanvas
 
 
-# We initialize glfw upon import
-glfw.init()
+def ensure_app():
+    # It is safe to call init multiple times:
+    # "Additional calls to this function after successful initialization
+    # but before termination will return GLFW_TRUE immediately."
+    glfw.init()
 
 
 def call_later(delay, callback, *args):
@@ -567,6 +505,7 @@ async def mainloop():
 
 
 def run():
+    ensure_app()
     loop = asyncio.get_event_loop()
     loop.create_task(mainloop())
     loop.run_forever()
